@@ -1,9 +1,9 @@
 from pool   import Pool
 from worker import Worker
-from value  import AsyncValue
+from value  import AsyncValue, AsyncList
 
 __author__     = "Henrik Tudborg"
 __license__    = "MIT"
-__version__    = "0.3.3"
+__version__    = "0.4.2"
 __maintainer__ = "Henrik Tudborg"
 __email__      = "henrik@tudb.org"
